Agent skill

Vectorize Triton Ascend Comparisons

by Krusty84 in Krusty84/triton-ascend-agent-dev-kit

Vectorize explicit integer comparisons in Triton-Ascend by casting bounded index vectors to float32 before tl.where or similar compute expressions.

Apache-2.0Auto-check passedAI & LLM Engineering

Install Vectorize Triton Ascend Comparisons

skills CLI
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill vectorize-triton-ascend-comparisons -a claude-code

Project install by default; add -g for ~/.claude/skills/.

GitHub CLI
$ gh skill install Krusty84/triton-ascend-agent-dev-kit vectorize-triton-ascend-comparisons --agent claude-code

Project scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).

Manual copy
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/vectorize-triton-ascend-comparisons .claude/skills/vectorize-triton-ascend-comparisons && rm -rf skills-src

Use ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.

Claude Code skills documentation · loads skills from .claude/skills/

Facts

Skill name
vectorize-triton-ascend-comparisons
GitHub stars
106
Token cost
~498 tokens
SKILL.md length
180 words
Files
1
Skills in repo
23
Repo updated
First seen
Licence
Apache-2.0

At a glance

Vectorize explicit integer comparisons in Triton-Ascend by casting bounded index vectors to float32 before tl.where or similar compute expressions.

  • Works in 5 steps: Identify comparisons used in compute… → Prove that all compared integer values… → Cast the index vector to tl.float32… → …
  • An agent observes scalarized int32
  • SKILL.md covers Goal, Workflow, Implementation Pattern and Ascend Guardrails, plus 1 more section
  • Instructions only: no scripts, shell commands, URLs or credentials in SKILL.md

What it does

Vectorize Triton Ascend Comparisons is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Vectorize explicit integer comparisons in Triton-Ascend by casting bounded index vectors to float32 before tl.where or similar compute expressions. Use when an agent observes scalarized int32 or int64 comparison code on Ascend NPU, especially in LayerNorm tail handling, while load/store masks already compile efficiently.

Its SKILL.md is about 500 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.

It sits in AI & LLM Engineering. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.

When your agent uses it

  • An agent observes scalarized int32
  • Int64 comparison code on Ascend NPU
  • Especially in LayerNorm tail handling
  • While load/store masks already compile efficiently

Example prompts

  • “/vectorize-triton-ascend-comparisons”

Requirements

  • Python 3

Workflow steps

5 steps, taken from the first numbered list in SKILL.md.

  1. Identify comparisons used in compute expressions such as tl.where, not only load/store masks.
  2. Prove that all compared integer values are exactly representable in float32.
  3. Cast the index vector to tl.float32 immediately before the comparison.
  4. Keep original integer offsets for pointer arithmetic and memory masks.
  5. Inspect performance and compare results around the tail boundary.

What it can do on your machine

Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.

  • Tool permissions

    Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.

    From allowed-tools in the SKILL.md frontmatter.

  • Runs code

    No scripts in the folder and no shell commands in SKILL.md (its code samples are python).

    From the folder's file list and the shell code blocks in SKILL.md.

  • Network

    No URLs in SKILL.md.

    From URLs in SKILL.md, links to its own repository left out.

  • Credentials

    Names no API keys, tokens, secrets or passwords.

    From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.

Context cost

Vectorize Triton Ascend Comparisons loads about 498 tokens when it runs. Until then it costs about 90 tokens; SKILL.md has 180 words of instructions outside code blocks.

Always · name and description, kept in context so the agent knows when to use it
~90
When it runs · the whole SKILL.md, loaded when a task matches
~498

Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.

Safety

Auto-check passed

The automated check found no risky patterns in SKILL.md.

Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.

SKILL.md

The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 180 words, ~498 tokens.

Download SKILL.mdSave it as .claude/skills/vectorize-triton-ascend-comparisons/SKILL.md (or your agent's skills folder).
name
vectorize-triton-ascend-comparisons
description
Vectorize explicit integer comparisons in Triton-Ascend by casting bounded index vectors to float32 before tl.where or similar compute expressions. Use when an agent observes scalarized int32 or int64 comparison code on Ascend NPU, especially in LayerNorm tail handling, while load/store masks already compile efficiently.

Vectorize Triton-Ascend Comparisons

Goal

Move eligible explicit comparisons onto Ascend vector cast and compare instructions without changing mask semantics.

Workflow

  1. Identify comparisons used in compute expressions such as tl.where, not only load/store masks.
  2. Prove that all compared integer values are exactly representable in float32.
  3. Cast the index vector to tl.float32 immediately before the comparison.
  4. Keep original integer offsets for pointer arithmetic and memory masks.
  5. Inspect performance and compare results around the tail boundary.

Implementation Pattern

python
cols = tl.arange(0, BLOCK_N)
mask = cols < N
x = tl.load(X + cols, mask=mask, other=0.0).to(tl.float32)

cols_cmp = cols.to(tl.float32)
centered = tl.where(cols_cmp < N, x - mean, 0.0)
variance = tl.sum(centered * centered, axis=0) / N

tl.store(Out + cols, (x - mean) / tl.sqrt(variance + eps), mask=mask)

Ascend Guardrails

  • Keep load and store masks in their natural integer form; the compiler commonly vectorizes them already.
  • Cast only the comparison operands, never pointers or offsets.
  • Float32 represents all integers exactly only through 2^24. Do not use this transformation when indices or bounds can exceed that range.
  • Compare x values, not the X pointer, inside tl.where.
  • Measure the generated kernel because compiler versions may optimize the integer form differently.

Verification

Test N immediately below, equal to, and above BLOCK_N boundaries. Compare the transformed and original kernels across valid ranges and add a guard test for N greater than 2^24.

© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file

Files

Just SKILL.md in skills/vectorize-triton-ascend-comparisons of Krusty84/triton-ascend-agent-dev-kit.

Open the folder on GitHubat commit 4ab5ee7

Compare with similar skills

Vectorize Triton Ascend Comparisons next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.

Vectorize Triton Ascend Comparisons compared with similar skills
SkillStarsUsed inTokensAuto-checkLicenceRepo updated
Vectorize Triton Ascend Comparisons this skillKrusty84/triton-ascend-agent-dev-kit106—~498Automated safety check: PassApache-2.0
Agent BuildershareAI-lab/learn-claude-code78k5 repos~1.2kAutomated safety check: PassMIT
Add Uint Supportpytorch/pytorch104k2 repos~2.3kAutomated safety check: PassCustom licence
LLM Benchmarking with lm-evaluation-harnessOrchestra-Research/AI-Research-SKILLs13k8 repos~3kAutomated safety check: PassMIT
Segment Anything Model GuideOrchestra-Research/AI-Research-SKILLs13k8 repos~3.3kAutomated safety check: PassMIT
1passwordtrpc-group/trpc-agent-go1.9k14 repos~656Automated safety check: PassApache-2.0

Similar skills

  • Agent Builder

    shareAI-lab/learn-claude-code

    Design and build AI agents for any domain. An agent skill from shareAI-lab/learn-claude-code.

    78k GitHub starsUsed in 5 repos~1.2k tokens
    AI & LLM EngineeringAuto-check passed
  • Add Uint Support

    pytorch/pytorch

    Add unsigned integer (uint) type support to PyTorch operators by updating ATDISPATCH macros.

    104k GitHub starsUsed in 2 repos~2.3k tokens
    AI & LLM EngineeringAuto-check passed
  • LLM Benchmarking with lm-evaluation-harness

    Orchestra-Research/AI-Research-SKILLs

    Runs lm-evaluation-harness to benchmark language models on academic suites such as MMLU, GSM8K and HumanEval, compare models and track training checkpoints.

    13k GitHub starsUsed in 8 repos~3k tokens
    AI & LLM EngineeringAuto-check passed
  • Segment Anything Model Guide

    Orchestra-Research/AI-Research-SKILLs

    Guide to using Meta's Segment Anything Model for zero-shot image segmentation with point, box or mask prompts, or automatic mask generation.

    13k GitHub starsUsed in 8 repos~3.3k tokens
    AI & LLM EngineeringAuto-check passed
  • 1password

    trpc-group/trpc-agent-go

    Set up and use 1Password CLI (op). An agent skill from trpc-group/trpc-agent-go.

    1.9k GitHub starsUsed in 14 repos~656 tokens
    AI & LLM EngineeringAuto-check passed
  • Planning With Files

    jarrodwatts/claude-code-config

    Transforms workflow to use Manus-style persistent markdown files for planning, progress tracking, and knowledge storage.

    1.1k GitHub starsUsed in 5 repos~967 tokens
    AI & LLM EngineeringAuto-check passed

More from Krusty84/triton-ascend-agent-dev-kit

All 23 skills in this repo
  • Triton-Ascend Token Pool Assignment

    Krusty84/triton-ascend-agent-dev-kit

    Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.

    106 GitHub stars~564 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Batch Token Reorder

    Krusty84/triton-ascend-agent-dev-kit

    Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.

    106 GitHub stars~597 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Binned MoE Routing

    Krusty84/triton-ascend-agent-dev-kit

    Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.

    106 GitHub stars~662 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Fused Attention

    Krusty84/triton-ascend-agent-dev-kit

    Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.

    106 GitHub stars~753 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Fused Softmax

    Krusty84/triton-ascend-agent-dev-kit

    Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.

    106 GitHub stars~636 tokensUpdated 1 mo ago
    Auto-check passed
  • Build Triton Ascend Layer Norm

    Krusty84/triton-ascend-agent-dev-kit

    Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.

    106 GitHub stars~659 tokensUpdated 1 mo ago
    Auto-check passed

Questions about Vectorize Triton Ascend Comparisons

What does Vectorize Triton Ascend Comparisons do?

Vectorize explicit integer comparisons in Triton-Ascend by casting bounded index vectors to float32 before tl.where or similar compute expressions. Vectorize Triton Ascend Comparisons is an agent skill from Krusty84/triton-ascend-agent-dev-kit.where or similar compute expressions.

When should I use Vectorize Triton Ascend Comparisons?

Vectorize Triton Ascend Comparisons fits situations like: an agent observes scalarized int32; int64 comparison code on Ascend NPU; especially in LayerNorm tail handling; while load/store masks already compile efficiently.

How do I install Vectorize Triton Ascend Comparisons in Claude Code?

Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill vectorize-triton-ascend-comparisons -a claude-code`. Or copy the skill folder (skills/vectorize-triton-ascend-comparisons in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/vectorize-triton-ascend-comparisons in your project. Claude Code loads it when a task matches its description.

How do I install Vectorize Triton Ascend Comparisons in Codex?

Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill vectorize-triton-ascend-comparisons -a codex`. Or copy the skill folder (skills/vectorize-triton-ascend-comparisons in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/vectorize-triton-ascend-comparisons in your project. Codex loads it when a task matches its description.

Can I use Vectorize Triton Ascend Comparisons in Cursor, Gemini CLI or GitHub Copilot?

Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill vectorize-triton-ascend-comparisons -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/vectorize-triton-ascend-comparisons, .gemini/skills/vectorize-triton-ascend-comparisons, .github/skills/vectorize-triton-ascend-comparisons and .opencode/skills/vectorize-triton-ascend-comparisons in your project.

What does Vectorize Triton Ascend Comparisons need to run?

SKILL.md names no scripts, command-line tools or credentials: Vectorize Triton Ascend Comparisons is instructions for the agent only. Our summary lists: Python 3.

Does Vectorize Triton Ascend Comparisons access the network?

SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.

Is Vectorize Triton Ascend Comparisons safe to install?

Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.

What licence does Vectorize Triton Ascend Comparisons use?

Vectorize Triton Ascend Comparisons is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.

How many tokens does Vectorize Triton Ascend Comparisons use?

About 498 tokens (SKILL.md is roughly 2k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.

What are the alternatives to Vectorize Triton Ascend Comparisons?

Skills that share tags, products or a category with Vectorize Triton Ascend Comparisons: Agent Builder (shareAI-lab/learn-claude-code, 78k stars), Add Uint Support (pytorch/pytorch, 104k stars), LLM Benchmarking with lm-evaluation-harness (Orchestra-Research/AI-Research-SKILLs, 13k stars) and Segment Anything Model Guide (Orchestra-Research/AI-Research-SKILLs, 13k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.

Who maintains Vectorize Triton Ascend Comparisons?

Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.

Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.